@@ -1,6 +1,6 @@
 !
-!  This file is part of MUMPS 5.6.1, released
-!  on Tue Jul 11 07:51:28 UTC 2023
+!  This file is part of MUMPS 5.6.2, released
+!  on Wed Oct 11 09:36:25 UTC 2023
 !
 !
 !  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
