@@ -1,6 +1,6 @@
 !
-!  This file is part of MUMPS 5.6.1, released
-!  on Tue Jul 11 07:51:28 UTC 2023
+!  This file is part of MUMPS 5.6.2, released
+!  on Wed Oct 11 09:36:25 UTC 2023
 !
 !
 !  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
@@ -172,7 +172,7 @@
         INTEGER,POINTER,DIMENSION(:) :: FRERE_STEPS, DAD_STEPS
         INTEGER,POINTER,DIMENSION(:) :: FILS, FRTPTR, FRTELT
         INTEGER(8),POINTER,DIMENSION(:) :: PTRAR, PTR8ARR
-        INTEGER,POINTER,DIMENSION(:) :: NINCOLARR, NINROWARR,PTRDEBARR
+        INTEGER,POINTER,DIMENSION(:) :: NINCOLARR,NINROWARR,PTRDEBARR
         INTEGER,POINTER,DIMENSION(:) :: NA, PROCNODE_STEPS
 !       Info for pruning tree 
         INTEGER,POINTER,DIMENSION(:) :: Step2node
